@@ -1,11 +1,11 @@
 import getpass
-uwWDp=object
-uwWDo=staticmethod
-uwWDc=False
-uwWDg=Exception
-uwWDq=None
-uwWDB=input
-uwWDP=list
+QRGSe=object
+QRGSN=staticmethod
+QRGSl=False
+QRGSj=Exception
+QRGSP=None
+QRGSb=input
+QRGSs=list
 import json
 import logging
 import sys
@@ -13,29 +13,29 @@ from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import load_file,safe_requests,save_file,to_str
 LOG=logging.getLogger(__name__)
-class AuthProvider(uwWDp):
- @uwWDo
+class AuthProvider(QRGSe):
+ @QRGSN
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @uwWDo
+ @QRGSN
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @uwWDo
- def get(provider,raise_error=uwWDc):
+ @QRGSN
+ def get(provider,raise_error=QRGSl):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise uwWDg(msg)
-   return uwWDq
+    raise QRGSj(msg)
+   return QRGSP
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @uwWDo
+ @QRGSN
  def name():
   return "internal"
  def get_or_create_token(self,username,password,headers):
@@ -46,28 +46,28 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or "{}"))
    return result["token"]
-  except uwWDg:
+  except QRGSj:
    pass
  def read_credentials(self,username):
   print("Please provide your login credentials below")
   if not username:
    sys.stdout.write("Username: ")
    sys.stdout.flush()
-   username=uwWDB()
+   username=QRGSb()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise uwWDg("Not implemented")
-def login(provider,username=uwWDq):
+  raise QRGSj("Not implemented")
+def login(provider,username=QRGSP):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=uwWDP(AuthProvider.providers().keys())
-  raise uwWDg('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=QRGSs(AuthProvider.providers().keys())
+  raise QRGSj('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print("Verifying credentials ... (this may take a few moments)")
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise uwWDg("Unable to verify login credentials - please try again")
+  raise QRGSj("Unable to verify login credentials - please try again")
  configs=load_config_file()
  configs["login"]={"provider":provider,"username":username,"token":token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
