@@ -1,10 +1,10 @@
 import logging
-djkmS=set
-djkmB=str
-djkmu=None
-djkmY=isinstance
-djkmG=list
-djkmQ=Exception
+Qgoel=set
+QgoeT=str
+QgoeI=None
+QgoeX=isinstance
+Qgoed=list
+Qgoep=Exception
 import re
 from email.header import Header
 from email.mime.image import MIMEImage
@@ -17,14 +17,14 @@ from localstack_ext import config
 from localstack_ext.bootstrap import smtplib_patched
 LOG=logging.getLogger(__name__)
 SENT_EMAILS=[]
-EMAIL_BLACKLIST=djkmS()
+EMAIL_BLACKLIST=Qgoel()
 def is_smtp_configured():
  return config.SMTP_HOST
 def get_canonical_email(email):
- email=re.sub(r"\s+","",djkmB(email or ""))
+ email=re.sub(r"\s+","",QgoeT(email or ""))
  email=email.strip().lower()
  return email
-def send_email(subject,message,recipients,from_email=djkmu,from_name=djkmu,smtp_host=djkmu,smtp_user=djkmu,smtp_pass=djkmu,images={}):
+def send_email(subject,message,recipients,from_email=QgoeI,from_name=QgoeI,smtp_host=QgoeI,smtp_user=QgoeI,smtp_pass=QgoeI,images={}):
  smtp_host=smtp_host or config.SMTP_HOST
  smtp_user=smtp_user or config.SMTP_USER
  smtp_pass=smtp_pass or config.SMTP_PASS
@@ -37,7 +37,7 @@ def send_email(subject,message,recipients,from_email=djkmu,from_name=djkmu,smtp_
    return
   LOG.debug('SMTP settings not configured, skip sending email to "%s"'%recipients)
   return
- recipients=recipients if djkmY(recipients,djkmG)else[recipients]
+ recipients=recipients if QgoeX(recipients,Qgoed)else[recipients]
  message=construct_message(subject,message,from_name,from_email,images=images)
  sign_message(message)
  for recipient in recipients:
@@ -49,12 +49,12 @@ def send_email(subject,message,recipients,from_email=djkmu,from_name=djkmu,smtp_
   s=smtplib_patched.SMTP(smtp_host)
   try:
    s.starttls()
-  except djkmQ as e:
+  except Qgoep as e:
    LOG.debug("Unable to run STARTTLS command on SMTP connection: %s"%e)
   if smtp_user and smtp_pass:
    try:
     s.login(smtp_user,smtp_pass)
-   except djkmQ as e:
+   except Qgoep as e:
     LOG.debug("Unable to run login/auth command against SMTP server, skipping: %s"%e)
   s.sendmail(from_email,[recipient],message.as_string())
   s.quit()
@@ -62,7 +62,7 @@ def sign_message(msg):
  pass
 def is_email_address(value):
  return re.match(r"[^@]+@[^@]+\.[^@]+",value or "")
-def construct_message(subject,message,from_name,from_email,images=djkmu):
+def construct_message(subject,message,from_name,from_email,images=QgoeI):
  result=MIMEText(message)
  if images:
   result=MIMEMultipart("related")
@@ -77,6 +77,6 @@ def construct_message(subject,message,from_name,from_email,images=djkmu):
    msg_image.add_header("Content-ID","<%s>"%image_id)
    result.attach(msg_image)
  result["Subject"]=subject
- result["From"]=formataddr((djkmB(Header(from_name,"utf-8")),from_email))
+ result["From"]=formataddr((QgoeT(Header(from_name,"utf-8")),from_email))
  return result
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
