@@ -1,7 +1,7 @@
 import logging
-BqFEC=False
-BqFEA=True
-BqFEG=Exception
+fzKgy=False
+fzKgi=True
+fzKgC=Exception
 import os
 import traceback
 import localstack
@@ -82,18 +82,18 @@ def setup_ssl_cert():
    return
  download_github_artifact(SSL_CERT_URL,target_file)
 def download_github_artifact(url,target_file):
- def do_download(url,print_error=BqFEC):
+ def do_download(url,print_error=fzKgy):
   try:
    download(url,target_file)
-   return BqFEA
-  except BqFEG as e:
+   return fzKgi
+  except fzKgC as e:
    if print_error:
     LOG.info("Unable to download local test SSL certificate from %s to %s: %s %s"%(url,target_file,e,traceback.format_exc()))
  result=do_download(url)
  if not result:
   url=url.replace("https://github.com","https://cdn.jsdelivr.net/gh")
   url=url.replace("/raw/master/","@master/")
-  do_download(url,BqFEA)
+  do_download(url,fzKgi)
 def install_h2():
  target_dir=os.path.join(INFRA_DIR,"h2")
  if not os.path.exists(target_dir):
