@@ -1,12 +1,12 @@
 import base64
-manok=True
-manoh=Exception
-manoQ=False
-manoJ=str
-manoc=len
-manoz=int
-manoA=range
-manoO=object
+ptcDa=True
+ptcDR=Exception
+ptcDk=False
+ptcDY=str
+ptcDG=len
+ptcDq=int
+ptcDM=range
+ptcDj=object
 import glob
 import json
 import logging
@@ -26,10 +26,10 @@ ENV_PREPARED={}
 MAX_KEY_CACHE_DURATION_SECS=60*60*24
 LOG=logging.getLogger(__name__)
 ENV_LOCALSTACK_API_KEY="LOCALSTACK_API_KEY"
-def read_api_key(raise_if_missing=manok):
+def read_api_key(raise_if_missing=ptcDa):
  key=(os.environ.get(ENV_LOCALSTACK_API_KEY)or "").strip()
  if not key and raise_if_missing:
-  raise manoh("Unable to retrieve API key. Please configure $%s in your environment"%ENV_LOCALSTACK_API_KEY)
+  raise ptcDR("Unable to retrieve API key. Please configure $%s in your environment"%ENV_LOCALSTACK_API_KEY)
  return key
 def fetch_key():
  api_key=read_api_key()
@@ -38,18 +38,18 @@ def fetch_key():
  data={"api_key":api_key,"version":__version__}
  try:
   logging.getLogger("py.warnings").setLevel(logging.ERROR)
-  result=requests.post("%s/activate"%config.API_URL,json.dumps(data),verify=manoQ)
+  result=requests.post("%s/activate"%config.API_URL,json.dumps(data),verify=ptcDk)
   if result.status_code>=400:
    content=result.content
    content_type=result.headers.get("Content-Type")
-   raise manoh('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
+   raise ptcDR('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
   key_base64=json.loads(to_str(result.content))["key"]
   cache_key_locally(api_key,key_base64)
- except manoh as e:
+ except ptcDR as e:
   if log_license_issues():
-   api_key=manoJ(api_key_configured()or "")
+   api_key=ptcDY(api_key_configured()or "")
    api_key_prefix=api_key[:3]
-   LOG.warning('Error activating API key "%s..."(%s): %s %s'%(api_key_prefix,manoc(api_key),e,traceback.format_exc()))
+   LOG.warning('Error activating API key "%s..."(%s): %s %s'%(api_key_prefix,ptcDG(api_key),e,traceback.format_exc()))
   key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger("py.warnings").setLevel(logging.WARNING)
@@ -57,25 +57,25 @@ def fetch_key():
  return decoded_key
 def cache_key_locally(api_key,key_b64):
  configs=localstack_config.load_config_file()
- timestamp=manoJ(manoz(now_utc()))
+ timestamp=ptcDY(ptcDq(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in manoA(manoc(timestamp)):
+ for i in ptcDM(ptcDG(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs["cached_key"]={"timestamp":manoz(timestamp),"key_hash":md5(api_key),"key":key_b64}
+ configs["cached_key"]={"timestamp":ptcDq(timestamp),"key_hash":md5(api_key),"key":key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
 def load_cached_key(api_key):
  configs=localstack_config.load_config_file()
  cached_key=configs["cached_key"]
  if cached_key.get("key_hash")!=md5(api_key):
-  raise manoh("Cached key was created for a different API key")
+  raise ptcDR("Cached key was created for a different API key")
  now=now_utc()
  if(now-cached_key["timestamp"])>MAX_KEY_CACHE_DURATION_SECS:
-  raise manoh("Cached key expired")
- timestamp=manoJ(cached_key["timestamp"])
+  raise ptcDR("Cached key expired")
+ timestamp=ptcDY(cached_key["timestamp"])
  key_raw=to_str(base64.b64decode(cached_key["key"]))
- for i in manoA(manoc(timestamp)):
+ for i in ptcDM(ptcDG(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -114,25 +114,25 @@ def cleanup_environment():
       if os.path.exists(delete_file):
        os.remove(delete_file)
 def prepare_environment():
- class OnClose(manoO):
+ class OnClose(ptcDj):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get("finalized"):
     cleanup_environment()
-   ENV_PREPARED["finalized"]=manok
+   ENV_PREPARED["finalized"]=ptcDa
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get("finalized"):
   try:
    key=fetch_key()
    if not key:
-    raise manoh("Unable to fetch and validate API key from environment")
+    raise ptcDR("Unable to fetch and validate API key from environment")
    if key!="test":
     decrypt_files(key)
     LOG.info("Successfully activated API key")
    else:
     LOG.info("Using test API key")
    os.environ[ENV_PRO_ACTIVATED]="1"
-  except manoh as e:
+  except ptcDR as e:
    if log_license_issues():
     LOG.warning("Unable to activate API key: %s %s"%(e,traceback.format_exc()))
    if config.REQUIRE_PRO:
@@ -142,18 +142,18 @@ def prepare_environment():
 def log_license_issues():
  return api_key_configured()and localstack_config.is_env_true("LOG_LICENSE_ISSUES")
 def api_key_configured():
- return read_api_key(raise_if_missing=manoQ)
+ return read_api_key(raise_if_missing=ptcDk)
 def is_logged_in():
  configs=localstack_config.load_config_file()
  login_info=configs.get("login")
  if not login_info:
-  return manoQ
- return manok
+  return ptcDk
+ return ptcDa
 def get_auth_headers():
  configs=localstack_config.load_config_file()
  login_info=configs.get("login")
  if not login_info:
-  raise manoh("Please log in first")
+  raise ptcDR("Please log in first")
  auth_token=login_info["token"]
  if not auth_token.startswith("%s "%login_info["provider"]):
   auth_token="%s %s"%(login_info["provider"],auth_token)
