@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-LNmfO=dict
-LNmfA=super
-LNmfb=hasattr
-LNmfz=Exception
-LNmfY=object
-LNmfG=dir
-LNmfT=None
-LNmfX=False
-LNmfS=True
-LNmfh=len
-LNmfB=set
+exThi=dict
+exThj=super
+exThg=hasattr
+exThV=Exception
+exThv=object
+exThn=dir
+exThl=None
+exThK=False
+exThW=True
+exThF=len
+exThz=set
 import errno
 import socket
 from select import select
 from socket import(AF_INET,AF_INET6,IPPROTO_IPV6,IPPROTO_TCP,IPV6_V6ONLY,SO_REUSEADDR,SOCK_STREAM,SOL_SOCKET,TCP_NODELAY)
-class AttrDict(LNmfO):
+class AttrDict(exThi):
  def __init__(self,*args,**kwargs):
-  LNmfA(AttrDict,self).__init__(*args,**kwargs)
+  exThj(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and LNmfb(socket,"IPV6_V6ONLY"):
+ if six and exThg(socket,"IPV6_V6ONLY"):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +37,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except LNmfz:
+ except exThV:
   pass
-class Server(LNmfY):
+class Server(exThv):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +51,17 @@ class Server(LNmfY):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(LNmfY):
- def __init__(self,opt,sock,addr,LNmfG):
+class Half(exThv):
+ def __init__(self,opt,sock,addr,exThn):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.LNmfG=LNmfG
-  self.name="peer" if self.LNmfG else "client"
+  self.exThn=exThn
+  self.name="peer" if self.exThn else "client"
   self.queue=[]
-  self.dest=LNmfT
-  self.err=LNmfT
-  self.ready=LNmfX
+  self.dest=exThl
+  self.err=exThl
+  self.ready=exThK
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,7 +72,7 @@ class Half(LNmfY):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=LNmfS
+   self.ready=exThW
    self.copy()
   return self.err
  def error(self,msg,e):
@@ -81,9 +81,9 @@ class Half(LNmfY):
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except LNmfz as e:
+  except exThV as e:
    return self.error("send error",e)
-  if n!=LNmfh(self.queue[0]):
+  if n!=exThF(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,17 +92,17 @@ class Half(LNmfY):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=LNmfX
+    self.ready=exThK
     return
    return self.error("recv socket error",e)
-  except LNmfz as e:
+  except exThV as e:
    return self.error("recv error",e)
-  if LNmfh(buf)==0:
+  if exThF(buf)==0:
    return self.error("eof",0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(LNmfY):
+class Proxy(exThv):
  def __init__(self,opt,sock,addr):
   self.opt=opt
   self.cl=Half(opt,sock,addr,"i")
@@ -110,7 +110,7 @@ class Proxy(LNmfY):
   self.peer=Half(opt,peer,addr,"o")
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=LNmfT
+  self.err=exThl
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -125,7 +125,7 @@ class Proxy(LNmfY):
   return self.err
 def server_loop(opt):
  qs=[]
- opt["ip6"]=opt.get("ip6",LNmfX)
+ opt["ip6"]=opt.get("ip6",exThK)
  opt["bind_addr"]=opt.get("bind_addr","0.0.0.0")
  opt["addr"]=opt.get("addr","127.0.0.1")
  opt["bind_port"]=opt.get("bind_port",0)
@@ -137,15 +137,15 @@ def server_loop(opt):
    q.pre_wait(rr,r,w,e)
   timeo=10.0 if not rr else 0.0
   r,w,e=select(r,w,e,timeo)
-  r=LNmfB(r).union(rr)
+  r=exThz(r).union(rr)
   for q in qs:
    if q.post_wait(r,w,e):
     qs.remove(q)
 def main():
- opt={"ip6":LNmfX,"bind_port":2223,"addr":"192.168.43.191","port":22}
- opt={"ip6":LNmfX,"bind_port":48429,"addr":"128.0.100.3","port":22}
- opt={"ip6":LNmfX,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
- opt={"ip6":LNmfX,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
+ opt={"ip6":exThK,"bind_port":2223,"addr":"192.168.43.191","port":22}
+ opt={"ip6":exThK,"bind_port":48429,"addr":"128.0.100.3","port":22}
+ opt={"ip6":exThK,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
+ opt={"ip6":exThK,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
  server_loop(opt)
 if __name__=="__main__":
  main()
