@@ -1,28 +1,34 @@
+import logging
+WkxaV=True
+Wkxah=False
+Wkxag=None
+Wkxay=Exception
+Wkxaw=open
+WkxaM=bool
+WkxaP=str
+Wkxaq=dict
+Wkxaz=list
+Wkxat=isinstance
+Wkxaj=super
 import os
-pEnmS=True
-pEnmi=False
-pEnmg=None
-pEnmG=Exception
-pEnmX=open
-pEnme=str
-pEnmR=dict
-pEnmU=list
-pEnmO=isinstance
 import sys
 from typing import Any,Callable,Dict,List
 import click
 from localstack.cli import LocalstackCli,LocalstackCliPlugin,console
 class ProCliPlugin(LocalstackCliPlugin):
  name="pro"
- def is_active(self):
+ def should_load(self):
   e=os.getenv("LOCALSTACK_API_KEY")
-  return pEnmS if e else pEnmi
- def attach(self,cli:LocalstackCli)->pEnmg:
+  return WkxaV if e else Wkxah
+ def is_active(self):
+  return self.should_load()
+ def attach(self,cli:LocalstackCli)->Wkxag:
   group:click.Group=cli.group
   group.add_command(cmd_login)
   group.add_command(cmd_logout)
   group.add_command(daemons)
   group.add_command(pod)
+  group.add_command(dns)
 @click.group(name="daemons",help="Manage local daemon processes")
 def daemons():
  pass
@@ -34,7 +40,7 @@ def cmd_login(username,provider):
  try:
   auth.login(provider,username)
   console.print("successfully logged in")
- except pEnmG as e:
+ except Wkxay as e:
   console.print("authentication error: %s"%e)
 @click.command(name="logout",help="Log out and delete any session tokens")
 def cmd_logout():
@@ -42,7 +48,7 @@ def cmd_logout():
  try:
   auth.logout()
   console.print("successfully logged out")
- except pEnmG as e:
+ except Wkxay as e:
   console.print("logout error: %s"%e)
 @daemons.command(name="start",help="Start local daemon processes")
 def cmd_daemons_start():
@@ -61,10 +67,22 @@ def cmd_daemons_log():
  if not os.path.isfile(file_path):
   console.print("no log found")
  else:
-  with pEnmX(file_path,"r")as fd:
+  with Wkxaw(file_path,"r")as fd:
    for line in fd:
     sys.stdout.write(line)
     sys.stdout.flush()
+@click.group(name="dns",help="Manage DNS settings of your host")
+def dns():
+ pass
+@dns.command(name="systemd-resolved",help="Manage DNS settings of systemd-resolved (Ubuntu, Debian etc.)")
+@click.option("--revert",is_flag=WkxaV,help="Revert systemd-resolved settings for the docker interface")
+def cmd_dns_systemd(revert:WkxaM):
+ import localstack_ext.services.dns_server
+ from localstack_ext.services.dns_server import configure_systemd
+ console.print("Configuring systemd-resolved...")
+ logger_name=localstack_ext.services.dns_server.LOG.name
+ localstack_ext.services.dns_server.LOG=ConsoleLogger(logger_name)
+ configure_systemd(revert)
 @click.group(name="pod",help="Manage state of local cloud pods")
 def pod():
  from localstack_ext.bootstrap.licensing import is_logged_in
@@ -79,11 +97,11 @@ def cmd_pod_list():
  from localstack.utils.common import format_bytes
  from localstack_ext.bootstrap import pods_client
  try:
-  result=pods_client.list_pods(pEnmg)
+  result=pods_client.list_pods(Wkxag)
   status.stop()
   columns={"pod_name":"Name","backend":"Backend","url":"URL","size":"Size","state":"State"}
   print_table(columns,result,formatters={"size":format_bytes})
- except pEnmG as e:
+ except Wkxay as e:
   status.stop()
   if config.DEBUG:
    console.print_exception()
@@ -95,32 +113,48 @@ def cmd_pod_create():
  console.print(msg)
 @pod.command(name="push",help="Push the state of the LocalStack instance to a cloud pod")
 @click.argument("name")
-def cmd_pod_push(name:pEnme):
+def cmd_pod_push(name:WkxaP):
  from localstack_ext.bootstrap import pods_client
- pods_client.push_state(name,pEnmg)
+ pods_client.push_state(name,Wkxag)
 @pod.command(name="pull",help="Pull the state of a cloud pod into the running LocalStack instance")
 @click.argument("name")
-def cmd_pod_pull(name:pEnme):
+def cmd_pod_pull(name:WkxaP):
  from localstack_ext.bootstrap import pods_client
- pods_client.pull_state(name,pEnmg)
-def print_table(columns:Dict[pEnme,pEnme],rows:List[Dict[pEnme,Any]],formatters:Dict[pEnme,Callable[[Any],pEnme]]=pEnmg):
+ pods_client.pull_state(name,Wkxag)
+@pod.command(name="reset",help="Reset the local state to get a fresh LocalStack instance")
+def cmd_pod_reset():
+ from localstack_ext.bootstrap import pods_client
+ pods_client.reset_local_state()
+def print_table(columns:Dict[WkxaP,WkxaP],rows:List[Dict[WkxaP,Any]],formatters:Dict[WkxaP,Callable[[Any],WkxaP]]=Wkxag):
  from rich.table import Table
- if formatters is pEnmg:
-  formatters=pEnmR()
+ if formatters is Wkxag:
+  formatters=Wkxaq()
  t=Table()
  for k,name in columns.items():
   t.add_column(name)
  for row in rows:
-  cells=pEnmU()
+  cells=Wkxaz()
   for c in columns.keys():
    cell=row.get(c)
    if c in formatters:
     cell=formatters[c](cell)
-   if cell is pEnmg:
+   if cell is Wkxag:
     cell=""
-   if not pEnmO(cell,pEnme):
-    cell=pEnme(cell)
+   if not Wkxat(cell,WkxaP):
+    cell=WkxaP(cell)
    cells.append(cell)
   t.add_row(*cells)
  console.print(t)
+class ConsoleLogger(logging.Logger):
+ def __init__(self,name):
+  Wkxaj().__init__(name)
+ def info(self,msg:Any,*args:Any,**kwargs:Any)->Wkxag:
+  console.print(msg%args)
+ def warning(self,msg:Any,*args:Any,**kwargs:Any)->Wkxag:
+  console.print("[red]Warning:[/red] ",msg%args)
+ def error(self,msg:Any,*args:Any,**kwargs:Any)->Wkxag:
+  console.print("[red]Error:[/red] ",msg%args)
+ def exception(self,msg:Any,*args:Any,**kwargs:Any)->Wkxag:
+  console.print("[red]Error:[/red] ",msg%args)
+  console.print_exception()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
