@@ -3,6 +3,7 @@ import re
 
 from localstack import config as localstack_config
 from localstack import constants as localstack_constants
+from localstack.constants import LOCALHOST_HOSTNAME
 from localstack.utils.docker import DOCKER_CLIENT
 
 FALSE_STRINGS = localstack_constants.FALSE_STRINGS
@@ -21,7 +22,11 @@ DB_PASS = os.environ.get("DB_PASS")
 
 # localhost IP address and hostname
 LOCALHOST_IP = "127.0.0.1"
-LOCAL_HOSTNAME = "localhost.localstack.cloud"
+
+# base domain name used for endpoints of created resources (e.g., CloudFront distributions)
+RESOURCES_BASE_DOMAIN_NAME = (
+    os.environ.get("RESOURCES_BASE_DOMAIN_NAME", "").strip() or LOCALHOST_HOSTNAME
+)
 
 # bind address of local DNS server
 DNS_ADDRESS = os.environ.get("DNS_ADDRESS") or "0.0.0.0"
@@ -45,12 +50,15 @@ SMTP_EMAIL = os.environ.get("SMTP_EMAIL", "")
 AUTOSTART_UTIL_CONTAINERS = localstack_config.is_env_true("AUTOSTART_UTIL_CONTAINERS")
 
 # optional flags to pass when starting the bigdata Docker container
-BIGDATA_DOCKER_FLAGS = os.environ.get("BIGDATA_DOCKER_FLAGS", "")
+BIGDATA_DOCKER_FLAGS = (os.environ.get("BIGDATA_DOCKER_FLAGS") or "").strip()
+
+# optional predefined hostname to use to connect from main container to localstack_bigdata container
+BIGDATA_HOST_FROM_MAIN = (os.environ.get("BIGDATA_HOST_FROM_MAIN") or "").strip()
 
 # Comma-separated list of regex patterns for DNS names to resolve locally.
 # Any DNS name not matched against any of the patterns on this whitelist
 # will resolve to the real DNS entry, rather than the local one.
-DNS_LOCAL_NAME_PATTERNS = os.environ.get("DNS_LOCAL_NAME_PATTERNS", "")
+DNS_LOCAL_NAME_PATTERNS = (os.environ.get("DNS_LOCAL_NAME_PATTERNS") or "").strip()
 
 # whether to use static ports and IDs (e.g., cf-<port>) for CloudFormation distributions
 CLOUDFRONT_STATIC_PORTS = localstack_config.is_env_true("CLOUDFRONT_STATIC_PORTS")
@@ -77,8 +85,8 @@ def use_custom_dns():
 # localstack_config.USE_SSL = os.environ.get('USE_SSL', '').lower().strip() not in FALSE_STRINGS
 
 # backend service ports
-DEFAULT_PORT_LOCAL_DAEMON = 4535
-DEFAULT_PORT_LOCAL_DAEMON_ROOT = 4534
+DEFAULT_PORT_LOCAL_DAEMON = 4600
+DEFAULT_PORT_LOCAL_DAEMON_ROOT = 4601
 
 # port ranges for service instances (e.g., Postgres DBs, ElastiCache clusters, ...)
 SERVICE_INSTANCES_PORTS_START = int(os.environ.get("SERVICE_INSTANCES_PORTS_START") or 4510)
