@@ -1,10 +1,10 @@
 import logging
-nItcC=Exception
-nItcg=any
-nItcM=str
-nItck=None
-nItcJ=False
-nItco=bool
+WGfkx=Exception
+WGfkc=any
+WGfkB=str
+WGfkT=None
+WGfkP=False
+WGfkM=bool
 import os
 import traceback
 from localstack import config as localstack_config
@@ -29,14 +29,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except nItcC:
+  except WGfkx:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled("ec2"):
     local_daemon.start_in_background()
-  except nItcC as e:
+  except WGfkx as e:
    LOG.warning("Unable to start local daemon process: %s"%e)
   if is_api_key_configured:
    if os.environ.get("EDGE_PORT")and not localstack_config.EDGE_PORT_HTTP:
@@ -68,7 +68,7 @@ def register_localstack_plugins():
    docker_flags+=["-p {a}:{p}:{p}".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols="udp"):
    docker_flags+=["-p {a}:{p}:{p}/udp".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if nItcg([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if WGfkc([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=["-p {start}-{end}:{start}-{end}".format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled("eks"):
   kube_config=os.path.expanduser("~/.kube/config")
@@ -204,24 +204,24 @@ def load_plugin_files():
   dashboard_extended.patch_dashboard()
   edge.patch_start_edge()
   patch_start_infra()
- except nItcC as e:
-  if "No module named" not in nItcM(e):
+ except WGfkx as e:
+  if "No module named" not in WGfkB(e):
    print("ERROR: %s %s"%(e,traceback.format_exc()))
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except nItcC:
-  start_metadata_service=nItck
+ except WGfkx:
+  start_metadata_service=WGfkT
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except nItcC:
+   except WGfkx:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=nItcJ
+   config_ext.ENFORCE_IAM=WGfkP
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -244,5 +244,5 @@ def _setup_logging():
  logging.getLogger("root").setLevel(logging.WARNING)
  logging.getLogger("").setLevel(logging.WARNING)
 def api_key_configured():
- return nItco(os.environ.get("LOCALSTACK_API_KEY"))
+ return WGfkM(os.environ.get("LOCALSTACK_API_KEY"))
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
