@@ -1,13 +1,13 @@
 from localstack.services.cloudformation.deployment_utils import(lambda_keys_to_lower,params_list_to_dict)
-bzdlg=staticmethod
-bzdlN=None
-bzdlW=super
-bzdlp=classmethod
+HIfPC=staticmethod
+HIfPk=None
+HIfPn=super
+HIfPT=classmethod
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
 from localstack.utils.aws import aws_stack
 from localstack_ext.utils.aws import aws_utils
 class AmplifyBranch(GenericBaseModel):
- @bzdlg
+ @HIfPC
  def cloudformation_type():
   return "AWS::Amplify::Branch"
  def fetch_state(self,stack_name,resources):
@@ -17,10 +17,10 @@ class AmplifyBranch(GenericBaseModel):
   branch_name=self.resolve_refs_recursively(stack_name,props["BranchName"],resources)
   branches=client.list_branches(appId=app_id)["branches"]
   branch=[b for b in branches if b["branchName"]==branch_name]
-  return(branch or[bzdlN])[0]
+  return(branch or[HIfPk])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("BranchName")
- @bzdlg
+ @HIfPC
  def get_deploy_templates():
   def get_amplify_branch_params(params,**kwargs):
    params=lambda_keys_to_lower()(params,**kwargs)
@@ -32,7 +32,7 @@ class AmplifyBranch(GenericBaseModel):
    return params
   return{"create":{"function":"create_branch","parameters":get_amplify_branch_params}}
 class AmplifyApp(GenericBaseModel):
- @bzdlg
+ @HIfPC
  def cloudformation_type():
   return "AWS::Amplify::App"
  def get_cfn_attribute(self,attribute_name):
@@ -42,7 +42,7 @@ class AmplifyApp(GenericBaseModel):
    return self.get_physical_resource_id(attribute_name)
   if attribute_name in["Arn"]:
    return self.props.get("appArn")
-  return bzdlW(AmplifyApp,self).get_cfn_attribute(attribute_name)
+  return HIfPn(AmplifyApp,self).get_cfn_attribute(attribute_name)
  def get_physical_resource_id(self,attribute,**kwargs):
   props=self.props
   app_id=props.get("appId")
@@ -51,16 +51,16 @@ class AmplifyApp(GenericBaseModel):
   if attribute in REF_ID_ATTRS:
    return app_id
   return props.get("appArn")or aws_utils.amplify_app_arn(app_id)
- @bzdlp
+ @HIfPT
  def fetch_details(self,app_name):
   client=aws_stack.connect_to_service("amplify")
   apps=client.list_apps()["apps"]
   apps=[a for a in apps if a["name"]==app_name]
-  return(apps or[bzdlN])[0]
+  return(apps or[HIfPk])[0]
  def fetch_state(self,stack_name,resources):
   app_name=self.resolve_refs_recursively(stack_name,self.props["Name"],resources)
   return self.fetch_details(app_name)
- @bzdlg
+ @HIfPC
  def get_deploy_templates():
   def get_amplify_app_params(params,**kwargs):
    if "IAMServiceRole" in params:
