@@ -1,19 +1,19 @@
 import json
-UOacI=staticmethod
-UOacT=classmethod
-UOacu=None
-UOaco=True
-UOacz=hasattr
-UOacK=Exception
-UOacX=super
+rXOSJ=staticmethod
+rXOSi=classmethod
+rXOSI=None
+rXOSc=True
+rXOSq=hasattr
+rXOSM=Exception
+rXOSd=super
 from localstack.services.cloudformation.service_models import(REF_ARN_ATTRS,REF_ID_ATTRS,GenericBaseModel)
 from localstack.utils.aws import aws_stack
-from localstack.utils.common import clone,keys_to_lower,to_str
+from localstack.utils.common import clone,keys_to_lower,select_attributes,to_str
 from localstack_ext.services.appsync import appsync_api
 from localstack_ext.services.cloudformation.service_models import LOG
 from localstack_ext.utils.aws import aws_utils
 class AppSyncResolver(GenericBaseModel):
- @UOacI
+ @rXOSJ
  def cloudformation_type():
   return "AWS::AppSync::Resolver"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -26,39 +26,39 @@ class AppSyncResolver(GenericBaseModel):
   field_name=props.get("FieldName")
   data_source_name=props.get("DataSourceName")
   return self.fetch_details(api_id,type_name,field_name,data_source_name)
- @UOacT
+ @rXOSi
  def fetch_details(cls,api_id,type_name,field_name,data_source_name):
   client=aws_stack.connect_to_service("appsync")
   resolvers=client.list_resolvers(apiId=api_id,typeName=type_name)["resolvers"]
   result=[r for r in resolvers if r.get("fieldName")==field_name and r.get("dataSourceName")==data_source_name]
-  return(result or[UOacu])[0]
+  return(result or[rXOSI])[0]
  def get_deploy_templates():
   def get_resolver_params(params,**kwargs):
    params=keys_to_lower(clone(params))
-   req_template=params.pop("requestMappingTemplateS3Location",UOacu)
-   res_template=params.pop("responseMappingTemplateS3Location",UOacu)
+   req_template=params.pop("requestMappingTemplateS3Location",rXOSI)
+   res_template=params.pop("responseMappingTemplateS3Location",rXOSI)
    if req_template:
-    tmpl=aws_utils.download_s3_object(req_template,as_str=UOaco)
+    tmpl=aws_utils.download_s3_object(req_template,as_str=rXOSc)
     if tmpl:
      params["requestMappingTemplate"]=tmpl
    if res_template:
-    tmpl=aws_utils.download_s3_object(res_template,as_str=UOaco)
+    tmpl=aws_utils.download_s3_object(res_template,as_str=rXOSc)
     if tmpl:
      params["responseMappingTemplate"]=tmpl
    return params
   return{"create":{"function":"create_resolver","parameters":get_resolver_params}}
 class GraphQLSchema(GenericBaseModel):
- @UOacI
+ @rXOSJ
  def cloudformation_type():
   return "AWS::AppSync::GraphQLSchema"
  def get_physical_resource_id(self,attribute,**kwargs):
   return "%s-GraphQLSchema"%self.props.get("ApiId")
- @UOacT
- def fetch_details(cls,api_id,definition=UOacu,s3_location=UOacu):
+ @rXOSi
+ def fetch_details(cls,api_id,definition=rXOSI,s3_location=rXOSI):
   client=aws_stack.connect_to_service("appsync")
   try:
    schema=client.get_introspection_schema(apiId=api_id,format="SDL")["schema"]
-   schema=schema.read()if UOacz(schema,"read")else schema
+   schema=schema.read()if rXOSq(schema,"read")else schema
    schema=to_str(schema)
    if schema.startswith("{"):
     schema=json.loads(schema)["schema"]
@@ -68,36 +68,49 @@ class GraphQLSchema(GenericBaseModel):
    elif s3_location:
     LOG.debug("Getting GraphQL schema definition from S3 not yet implemented")
     return{"schema":definition}
-  except UOacK:
+  except rXOSM:
    pass
 class AppSyncApiKey(GenericBaseModel):
- @UOacI
+ @rXOSJ
  def cloudformation_type():
   return "AWS::AppSync::ApiKey"
  def get_cfn_attribute(self,attribute_name):
   props=self.props
   if attribute_name=="ApiKey":
    return "key-%s"%props["ApiId"]
-  if attribute_name in REF_ID_ATTRS:
-   key_id=props.get("ApiKeyId")or props.get("id")
-   return aws_utils.appsync_api_key_arn(props.get("ApiId"),key_id)
-  return UOacX(AppSyncApiKey,self).get_cfn_attribute(attribute_name)
+  if attribute_name in REF_ID_ATTRS+REF_ARN_ATTRS:
+   return self.get_physical_resource_id()
+  return rXOSd(AppSyncApiKey,self).get_cfn_attribute(attribute_name)
+ def get_physical_resource_id(self,attribute=rXOSI,**kwargs):
+  props=self.props
+  key_id=props.get("ApiKeyId")or props.get("id")
+  if not key_id or not props.get("ApiId"):
+   return
+  return aws_utils.appsync_api_key_arn(props.get("ApiId"),key_id)
  def fetch_state(self,stack_name,resources):
+  client=aws_stack.connect_to_service("appsync")
   props=self.props
   api_id=props.get("ApiId")
   api_id=self.resolve_refs_recursively(stack_name,api_id,resources)
-  keys=aws_stack.connect_to_service("appsync").list_api_keys(apiId=api_id)["apiKeys"]
-  result=[k for k in keys if k.get("description")==props.get("Description")and k.get("expires")==props.get("Expires")]
-  return(result or[UOacu])[0]
- @UOacI
- def get_deploy_templates():
-  result={"create":{"function":"create_api_key","parameters":{"apiId":"ApiId","description":"Description","expires":"Expires"}}}
-  return result
+  keys=client.list_api_keys(apiId=api_id).get("apiKeys",[])
+  result=[k for k in keys if k.get("description")==props.get("Description")and props.get("Expires")in[rXOSI,k.get("expires")]]
+  return(result or[rXOSI])[0]
+ @rXOSi
+ def get_deploy_templates(cls):
+  def _create_params(_,resources,resource_id,**kwargs):
+   resource=cls(resources[resource_id])
+   res_props=resource.properties
+   if not res_props.get("Description"):
+    api_id=resource.resolve_refs_recursively(kwargs.get("stack_name"),res_props.get("ApiId"),resources)
+    res_props["Description"]=f"Generated API key for AppSync API ID {api_id}"
+   result=keys_to_lower(select_attributes(res_props,["ApiId","Description","Expires"]))
+   return result
+  return{"create":{"function":"create_api_key","parameters":_create_params}}
 class AppSyncDataSource(GenericBaseModel):
- @UOacI
+ @rXOSJ
  def cloudformation_type():
   return "AWS::AppSync::DataSource"
- @UOacI
+ @rXOSJ
  def get_deploy_templates():
   def lambda_get_datasource_config(params,**kwargs):
    params=keys_to_lower(clone(params))
@@ -110,8 +123,8 @@ class AppSyncDataSource(GenericBaseModel):
    return self.props.get("dataSourceArn")
   if attribute_name=="Name":
    return self.props.get("name")
-  return UOacX(AppSyncDataSource,self).get_cfn_attribute(attribute_name)
- def get_physical_resource_id(self,attribute=UOacu,**kwargs):
+  return rXOSd(AppSyncDataSource,self).get_cfn_attribute(attribute_name)
+ def get_physical_resource_id(self,attribute=rXOSI,**kwargs):
   return self.props.get("dataSourceArn")
  def fetch_state(self,stack_name,resources):
   props=self.props
@@ -120,9 +133,9 @@ class AppSyncDataSource(GenericBaseModel):
   ds_name=self.resolve_refs_recursively(stack_name,ds_name,resources)
   api_id=self.resolve_refs_recursively(stack_name,props.get("ApiId"),resources)
   sources=client.list_data_sources(apiId=api_id)["dataSources"]
-  return([s for s in sources if s["name"]==ds_name]or[UOacu])[0]
+  return([s for s in sources if s["name"]==ds_name]or[rXOSI])[0]
 class AppSyncFunctionConfig(GenericBaseModel):
- @UOacI
+ @rXOSJ
  def cloudformation_type():
   return "AWS::AppSync::FunctionConfiguration"
  def fetch_state(self,stack_name,resources):
@@ -132,7 +145,7 @@ class AppSyncFunctionConfig(GenericBaseModel):
   name=self.resolve_refs_recursively(stack_name,props["Name"],resources)
   result=client.list_functions(apiId=api_id).get("functions",[])
   result=[f for f in result if f.get("name")==name]
-  return(result or[UOacu])[0]
+  return(result or[rXOSI])[0]
  def get_cfn_attribute(self,attribute_name):
   props=self.props
   if attribute_name=="FunctionId":
@@ -143,10 +156,10 @@ class AppSyncFunctionConfig(GenericBaseModel):
    return props.get("name")
   if attribute_name=="DataSourceName":
    return props.get("dataSourceName")
-  return UOacX(AppSyncFunctionConfig,self).get_cfn_attribute(attribute_name)
+  return rXOSd(AppSyncFunctionConfig,self).get_cfn_attribute(attribute_name)
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("functionArn")
- @UOacI
+ @rXOSJ
  def get_deploy_templates():
   def func_params(params,**kwargs):
    sys_cfg=params.get("SyncConfig")
@@ -157,7 +170,7 @@ class AppSyncFunctionConfig(GenericBaseModel):
    return result
   return{"create":{"function":"create_function","parameters":func_params}}
 class GraphQLAPI(GenericBaseModel):
- @UOacI
+ @rXOSJ
  def cloudformation_type():
   return "AWS::AppSync::GraphQLApi"
  def get_cfn_attribute(self,attribute_name):
@@ -165,21 +178,21 @@ class GraphQLAPI(GenericBaseModel):
   if not props.get("apiId"):
    details=self.fetch_details(props.get("Name"))
    if not details:
-    raise UOacK('Unable to find GraphQL API named "%s"'%props.get("Name"))
+    raise rXOSM('Unable to find GraphQL API named "%s"'%props.get("Name"))
    props["apiId"]=details["apiId"]
   if attribute_name=="ApiId":
    return props.get("apiId")
   if attribute_name in REF_ARN_ATTRS:
    return self.get_physical_resource_id(attribute_name)
   if attribute_name=="GraphQLUrl":
-   return appsync_api.get_graphql_url(props["apiId"],use_domain_name=UOaco)
-  return UOacX(GraphQLAPI,self).get_cfn_attribute(attribute_name)
+   return appsync_api.get_graphql_url(props["apiId"],use_domain_name=rXOSc)
+  return rXOSd(GraphQLAPI,self).get_cfn_attribute(attribute_name)
  def get_physical_resource_id(self,attribute,**kwargs):
   props=self.props
   return props.get("apiId")and aws_utils.appsync_api_arn(props["apiId"])
- @UOacT
+ @rXOSi
  def fetch_details(cls,api_name):
   client=aws_stack.connect_to_service("appsync")
   apis=client.list_graphql_apis()["graphqlApis"]
-  return([a for a in apis if a["name"]==api_name]or[UOacu])[0]
+  return([a for a in apis if a["name"]==api_name]or[rXOSI])[0]
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
