@@ -1,20 +1,20 @@
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
-BtdrQ=staticmethod
-BtdrJ=None
-Btdrc=super
-BtdrL=classmethod
-BtdrA=isinstance
-Btdre=list
-Btdrf=set
-Btdrb=False
-Btdrh=str
-BtdrH=dict
-Btdrj=len
+fdiYA=staticmethod
+fdiYT=None
+fdiYG=super
+fdiYO=classmethod
+fdiYy=isinstance
+fdiYD=list
+fdiYk=set
+fdiYs=False
+fdiYa=str
+fdiYM=dict
+fdiYu=len
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import select_attributes,short_uid,to_bytes
 from localstack_ext.utils.aws import aws_utils
 class CloudFrontOriginAccessIdentity(GenericBaseModel):
- @BtdrQ
+ @fdiYA
  def cloudformation_type():
   return "AWS::CloudFront::CloudFrontOriginAccessIdentity"
  def fetch_state(self,stack_name,resources):
@@ -23,8 +23,8 @@ class CloudFrontOriginAccessIdentity(GenericBaseModel):
   result=result.get("CloudFrontOriginAccessIdentityList",{}).get("Items",[])
   config=self.props.get("CloudFrontOriginAccessIdentityConfig",{})
   result=[r for r in result if r["Comment"]==config.get("Comment")]
-  return result and result[0]or BtdrJ
- @BtdrQ
+  return result and result[0]or fdiYT
+ @fdiYA
  def get_deploy_templates():
   def _params(params,**kwargs):
    config=params.get("CloudFrontOriginAccessIdentityConfig")
@@ -32,7 +32,7 @@ class CloudFrontOriginAccessIdentity(GenericBaseModel):
    return params
   return{"create":{"function":"create_cloud_front_origin_access_identity","parameters":_params}}
 class CloudFrontFunction(GenericBaseModel):
- @BtdrQ
+ @fdiYA
  def cloudformation_type():
   return "AWS::CloudFront::Function"
  def fetch_state(self,stack_name,resources):
@@ -41,14 +41,14 @@ class CloudFrontFunction(GenericBaseModel):
   result=result.get("FunctionList",{}).get("Items",[])
   props=self.props
   result=[r for r in result if r["Name"]==props.get("Name")]
-  return result and result[0]or BtdrJ
+  return result and result[0]or fdiYT
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("Name")
  def get_cfn_attribute(self,attribute_name):
   if attribute_name=="FunctionARN":
    return aws_utils.get_cloudfront_function_arn(self.props.get("Name"))
-  return Btdrc(CloudFrontFunction,self).get_cfn_attribute(attribute_name)
- @BtdrL
+  return fdiYG(CloudFrontFunction,self).get_cfn_attribute(attribute_name)
+ @fdiYO
  def get_deploy_templates(cls):
   def _params(params,**kwargs):
    result=select_attributes(params,["Name","FunctionCode","FunctionConfig"])
@@ -63,7 +63,7 @@ class CloudFrontFunction(GenericBaseModel):
    return client.delete_function(Name=name,IfMatch=etag)
   return{"create":{"function":"create_function","parameters":_params},"delete":{"function":_delete_function}}
 class CloudFrontOriginRequestPolicy(GenericBaseModel):
- @BtdrQ
+ @fdiYA
  def cloudformation_type():
   return "AWS::CloudFront::OriginRequestPolicy"
  def fetch_state(self,stack_name,resources):
@@ -75,10 +75,10 @@ class CloudFrontOriginRequestPolicy(GenericBaseModel):
   policy_name=self.props.get("OriginRequestPolicyConfig",{}).get("Name")
   policy_name=self.resolve_refs_recursively(stack_name,policy_name,resources)
   result=[r for r in result if r.get("Name")==policy_name]
-  return result and result[0]or BtdrJ
+  return result and result[0]or fdiYT
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("Id")
- @BtdrL
+ @fdiYO
  def get_deploy_templates(cls):
   def _delete_policy(resource_id,resources,resource_type,func,stack_name,*args):
    client=aws_stack.connect_to_service("cloudfront")
@@ -89,7 +89,7 @@ class CloudFrontOriginRequestPolicy(GenericBaseModel):
    return client.delete_origin_request_policy(Id=policy_id,IfMatch=etag)
   return{"create":{"function":"create_origin_request_policy"},"delete":{"function":_delete_policy}}
 class CloudFrontDistribution(GenericBaseModel):
- @BtdrQ
+ @fdiYA
  def cloudformation_type():
   return "AWS::CloudFront::Distribution"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -102,34 +102,34 @@ class CloudFrontDistribution(GenericBaseModel):
   distrs=client.list_distributions()["DistributionList"].get("Items",[])
   props=self.props["DistributionConfig"]
   origins=props.get("Origins",[])
-  origins=origins if BtdrA(origins,Btdre)else origins.get("Items")
-  origins_to_create=Btdrf([orig["DomainName"]for orig in origins])
+  origins=origins if fdiYy(origins,fdiYD)else origins.get("Items")
+  origins_to_create=fdiYk([orig["DomainName"]for orig in origins])
   aliases=props.get("Aliases",[])
-  aliases=aliases if BtdrA(aliases,Btdre)else aliases.get("Items")
-  aliases_to_create=Btdrf(aliases)
+  aliases=aliases if fdiYy(aliases,fdiYD)else aliases.get("Items")
+  aliases_to_create=fdiYk(aliases)
   for distr in distrs:
-   origins=Btdrf([orig.get("DomainName")for orig in distr.get("Origins",{})["Items"]])
-   aliases=Btdrf(distr.get("Aliases",{}).get("Items",[]))
+   origins=fdiYk([orig.get("DomainName")for orig in distr.get("Origins",{})["Items"]])
+   aliases=fdiYk(distr.get("Aliases",{}).get("Items",[]))
    if origins_to_create==origins and aliases_to_create==aliases:
     return distr
- @BtdrQ
+ @fdiYA
  def get_deploy_templates():
   def lambda_get_distribution_config(params,**kwargs):
    config=params["DistributionConfig"]
    config["CallerReference"]=config.get("CallerReference")or short_uid()
    config["Comment"]=config.get("Comment")or ""
-   config["IsIPV6Enabled"]=config.pop("IPV6Enabled",Btdrb)
-   config["Enabled"]=Btdrh(config.get("Enabled")).lower()=="true"
+   config["IsIPV6Enabled"]=config.pop("IPV6Enabled",fdiYs)
+   config["Enabled"]=fdiYa(config.get("Enabled")).lower()=="true"
    cert=config["ViewerCertificate"]=config.get("ViewerCertificate",{})
    custom_errors=config.get("CustomErrorResponses",[])
-   custom_errors=(custom_errors.get("Items",[])if BtdrA(custom_errors,BtdrH)else custom_errors)
+   custom_errors=(custom_errors.get("Items",[])if fdiYy(custom_errors,fdiYM)else custom_errors)
    for item in custom_errors:
-    item["ResponseCode"]=Btdrh(item.get("ResponseCode"))
+    item["ResponseCode"]=fdiYa(item.get("ResponseCode"))
    cache=config["DefaultCacheBehavior"]
-   cache["TrustedSigners"]=cache.get("TrustedSigners")or{"Quantity":0,"Enabled":Btdrb}
+   cache["TrustedSigners"]=cache.get("TrustedSigners")or{"Quantity":0,"Enabled":fdiYs}
    cache["MinTTL"]=cache.get("MinTTL")or 600
    forwarded=cache["ForwardedValues"]=cache.get("ForwardedValues",{})
-   forwarded["QueryString"]=Btdrh(forwarded.get("QueryString")).lower()=="true"
+   forwarded["QueryString"]=fdiYa(forwarded.get("QueryString")).lower()=="true"
    if "AcmCertificateArn" in cert:
     cert["ACMCertificateArn"]=cert.pop("AcmCertificateArn")
    if "SslSupportMethod" in cert:
@@ -137,14 +137,14 @@ class CloudFrontDistribution(GenericBaseModel):
    if "IamCertificateId" in cert:
     cert["IAMCertificateId"]=cert.pop("IamCertificateId")
    params["Tags"]={"Items":params.get("Tags")or[]}
-   def convert_list(key,parent=BtdrJ):
-    parent=config if parent is BtdrJ else parent
+   def convert_list(key,parent=fdiYT):
+    parent=config if parent is fdiYT else parent
     items=parent.get(key)or[]
-    if BtdrA(items,BtdrH)and "Items" in items and "Quantity" in items:
+    if fdiYy(items,fdiYM)and "Items" in items and "Quantity" in items:
      return
-    parent[key]={"Quantity":Btdrj(items),"Items":items}
+    parent[key]={"Quantity":fdiYu(items),"Items":items}
    cache_behavs=config.get("CacheBehaviors",[])
-   cache_behavs=(cache_behavs.get("Items",[])if BtdrA(cache_behavs,BtdrH)else cache_behavs)
+   cache_behavs=(cache_behavs.get("Items",[])if fdiYy(cache_behavs,fdiYM)else cache_behavs)
    for cb in cache_behavs:
     convert_list("AllowedMethods",cb)
     cb["AllowedMethods"]["CachedMethods"]=cb.pop("CachedMethods",[])
