@@ -1,19 +1,19 @@
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
-XoeHK=staticmethod
-XoeHE=None
+JqMAQ=staticmethod
+JqMAk=None
 from localstack.utils.aws import aws_stack
 class CloudTrail(GenericBaseModel):
- @XoeHK
+ @JqMAQ
  def cloudformation_type():
   return "AWS::CloudTrail::Trail"
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("cloudtrail")
   result=[t for t in client.list_trails()["Trails"]if t["Name"]==self.props["TrailName"]]
-  return(result or[XoeHE])[0]
+  return(result or[JqMAk])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   if attribute in REF_ID_ATTRS:
    return self.props["TrailName"]
- @XoeHK
+ @JqMAQ
  def get_deploy_templates():
   def put_event_selectors(resource_id,resources,*args,**kwargs):
    resource=resources[resource_id]
