@@ -1,11 +1,11 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-kmAGz=staticmethod
-kmAGu=None
-kmAGp=False
+OdVQP=staticmethod
+OdVQv=None
+OdVQB=False
 from localstack.utils.aws import aws_stack
 from localstack_ext.utils.aws import aws_utils
 class ECRRepository(GenericBaseModel):
- @kmAGz
+ @OdVQP
  def cloudformation_type():
   return "AWS::ECR::Repository"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -20,13 +20,13 @@ class ECRRepository(GenericBaseModel):
   registry_id=props.get("LifecyclePolicy",{}).get("RegistryId")
   kwargs={"registryId":registry_id}if registry_id else{}
   result=client.describe_repositories(repositoryNames=[repo_name],**kwargs).get("repositories",[])
-  return(result or[kmAGu])[0]
- @kmAGz
+  return(result or[OdVQv])[0]
+ @OdVQP
  def get_deploy_templates():
   def _create_params(params,**kwargs):
    encryption_type=params.get("EncryptionConfiguration",{}).get("EncryptionType","AES-256")
-   response={"repositoryName":params["RepositoryName"],"tags":params.get("Tags",[]),"imageTagMutability":params.get("ImageTagMutability","MUTABLE"),"imageScanningConfiguration":{"scanOnPush":params.get("ImageScanningConfiguration",{}).get("ScanOnPush",kmAGp)},"encryptionConfiguration":{"encryptionType":encryption_type}}
-   if(encryption_type=="KMS" and params.get("EncryptionConfiguration",{}).get("KmsKey")is not kmAGu):
+   response={"repositoryName":params["RepositoryName"],"tags":params.get("Tags",[]),"imageTagMutability":params.get("ImageTagMutability","MUTABLE"),"imageScanningConfiguration":{"scanOnPush":params.get("ImageScanningConfiguration",{}).get("ScanOnPush",OdVQB)},"encryptionConfiguration":{"encryptionType":encryption_type}}
+   if(encryption_type=="KMS" and params.get("EncryptionConfiguration",{}).get("KmsKey")is not OdVQv):
     response["encryptionConfiguration"]["kmsKey"]=params["EncryptionConfiguration"]["KmsKey"]
    return response
   result={"create":{"function":"create_repository","parameters":_create_params},"delete":{"function":"delete_repository","parameters":{"repositoryName":"RepositoryName"}}}
