@@ -1,13 +1,13 @@
 from localstack.services.cloudformation.deployment_utils import lambda_keys_to_lower
-whYiC=staticmethod
-whYiG=None
-whYiy=super
-whYip=str
+SEbpA=staticmethod
+SEbpG=None
+SEbpc=super
+SEbpg=str
 from localstack.services.cloudformation.service_models import GenericBaseModel
 from localstack.utils.aws import aws_stack
 from localstack_ext.services.cloudformation.service_models import(lambda_add_tags,lambda_convert_types)
 class ECSCluster(GenericBaseModel):
- @whYiC
+ @SEbpA
  def cloudformation_type():
   return "AWS::ECS::Cluster"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -19,12 +19,12 @@ class ECSCluster(GenericBaseModel):
   cluster=self.resolve_refs_recursively(stack_name,props.get("ClusterName"),resources)
   ecs_client=aws_stack.connect_to_service("ecs")
   result=ecs_client.describe_clusters(clusters=[cluster])["clusters"]
-  return(result or[whYiG])[0]
- @whYiC
+  return(result or[SEbpG])[0]
+ @SEbpA
  def get_deploy_templates():
   return{"create":{"function":"create_cluster","parameters":lambda_keys_to_lower()}}
 class ECSService(GenericBaseModel):
- @whYiC
+ @SEbpA
  def cloudformation_type():
   return "AWS::ECS::Service"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -35,16 +35,16 @@ class ECSService(GenericBaseModel):
   service_name=self.resolve_refs_recursively(stack_name,props.get("ServiceName"),resources)
   ecs_client=aws_stack.connect_to_service("ecs")
   result=ecs_client.describe_services(cluster=cluster,services=[service_name])["services"]
-  return(result or[whYiG])[0]
+  return(result or[SEbpG])[0]
  def get_cfn_attribute(self,attribute_name):
   if attribute_name=="Name":
    return self.props.get("ServiceName")
-  return whYiy(ECSService,self).get_cfn_attribute(attribute_name)
- @whYiC
+  return SEbpc(ECSService,self).get_cfn_attribute(attribute_name)
+ @SEbpA
  def get_deploy_templates():
   return{"create":{"function":"create_service","parameters":lambda_add_tags(lambda_keys_to_lower())}}
 class ECSTaskDefinition(GenericBaseModel):
- @whYiC
+ @SEbpA
  def cloudformation_type():
   return "AWS::ECS::TaskDefinition"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -54,8 +54,8 @@ class ECSTaskDefinition(GenericBaseModel):
   task_def=self.resolve_refs_recursively(stack_name,task_def,resources)
   ecs_client=aws_stack.connect_to_service("ecs")
   task_defs=ecs_client.list_task_definitions(familyPrefix=task_def)["taskDefinitionArns"]
-  return task_defs and{"taskDefinitionArn":task_defs[0]}or whYiG
- @whYiC
+  return task_defs and{"taskDefinitionArn":task_defs[0]}or SEbpG
+ @SEbpA
  def get_deploy_templates():
-  return{"create":{"function":"register_task_definition","parameters":lambda_convert_types(lambda_keys_to_lower(),{".memory":whYip,".cpu":whYip})}}
+  return{"create":{"function":"register_task_definition","parameters":lambda_convert_types(lambda_keys_to_lower(),{".memory":SEbpg,".cpu":SEbpg})}}
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
