@@ -1,29 +1,29 @@
 from localstack import config
-NhFzm=staticmethod
-NhFzA=None
-NhFzb=classmethod
-NhFzr=str
-NhFzw=False
-NhFzI=True
-NhFzW=super
+NLIjl=staticmethod
+NLIjz=None
+NLIjk=classmethod
+NLIjd=str
+NLIjo=False
+NLIjA=True
+NLIjE=super
 from localstack.services.cloudformation.service_models import GenericBaseModel
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import clone,items_equivalent
 from localstack_ext import config as ext_config
 from localstack_ext.services.cloudformation.service_models import LOG
 class ELBV2TargetGroup(GenericBaseModel):
- @NhFzm
+ @NLIjl
  def cloudformation_type():
   return "AWS::ElasticLoadBalancingV2::TargetGroup"
- def get_physical_resource_id(self,attribute=NhFzA,**kwargs):
+ def get_physical_resource_id(self,attribute=NLIjz,**kwargs):
   return self.props.get("TargetGroupArn")
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("elbv2")
   group_name=self.resolve_refs_recursively(stack_name,self.props.get("Name"),resources)
   result=client.describe_target_groups()["TargetGroups"]
   result=[g for g in result if g.get("TargetGroupName")==group_name]
-  return(result or[NhFzA])[0]
- @NhFzb
+  return(result or[NLIjz])[0]
+ @NLIjk
  def get_deploy_templates(cls):
   def register_targets(resource_id,resources,resource_type,func,stack_name,*args,**kwargs):
    resource=cls(resources[resource_id])
@@ -42,12 +42,12 @@ class ELBV2TargetGroup(GenericBaseModel):
     client=aws_stack.connect_to_service("elbv2")
     group_arn=props.get("TargetGroupArn")
     for attr in attrs:
-     attr["Value"]=NhFzr(attr.get("Value",""))
+     attr["Value"]=NLIjd(attr.get("Value",""))
     client.modify_target_group_attributes(TargetGroupArn=group_arn,Attributes=attrs)
   param_names=["Name","Protocol","ProtocolVersion","Port","VpcId","HealthCheckProtocol","HealthCheckPort","HealthCheckEnabled","HealthCheckPath","HealthCheckIntervalSeconds","HealthCheckTimeoutSeconds","HealthyThresholdCount","UnhealthyThresholdCount","Matcher","TargetType","Tags"]
   return{"create":[{"function":"create_target_group","parameters":param_names},{"function":register_targets},{"function":modify_target_group_attributes}]}
 class ELBV2ListenerRule(GenericBaseModel):
- @NhFzm
+ @NLIjl
  def cloudformation_type():
   return "AWS::ElasticLoadBalancingV2::ListenerRule"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -58,25 +58,25 @@ class ELBV2ListenerRule(GenericBaseModel):
     auth_config=action.get("AuthenticateCognitoConfig",{})
     for f in["Type","Order"]:
      if action.get(f)!=_action.get(f):
-      return NhFzw
+      return NLIjo
     _auth_config=_action.get("AuthenticateCognitoConfig",{})
     for f in["UserPoolArn","UserPoolClientId","UserPoolDomain"]:
      if auth_config.get(f)!=_auth_config.get(f):
-      return NhFzw
-    return NhFzI
+      return NLIjo
+    return NLIjA
    actions1=rule.get("Actions",[])
    return items_equivalent(actions,actions1,_matches)
   def conditions_match(rule):
    def _matches(cond,_cond):
     cond_values_wrapper=([cond.get(a)for a in candidate_attrs if cond.get(a)]+[cond])[0]
     if cond.get("Field")!=_cond.get("Field"):
-     return NhFzw
+     return NLIjo
     for cand in candidate_attrs:
      _cond=_cond.get(cand)or _cond
     cond_values=cond_values_wrapper.get("Values",[])
     if cond_values!=_cond.get("Values"):
-     return NhFzw
-    return NhFzI
+     return NLIjo
+    return NLIjA
    conditions1=rule.get("Conditions",[])
    candidate_attrs=["HostHeaderConfig","HttpHeaderConfig","HttpRequestMethodConfig","PathPatternConfig","QueryStringConfig","SourceIpConfig"]
    return items_equivalent(conditions,conditions1,_matches)
@@ -87,12 +87,12 @@ class ELBV2ListenerRule(GenericBaseModel):
   list_arn=self.resolve_refs_recursively(stack_name,rp.get("ListenerArn"),resources)
   result=client.describe_rules(ListenerArn=list_arn)["Rules"]
   result=[r for r in result if actions_match(r)and conditions_match(r)]
-  return(result or[NhFzA])[0]
- @NhFzm
+  return(result or[NLIjz])[0]
+ @NLIjl
  def get_deploy_templates():
   return{"create":{"function":"create_rule"}}
 class ELBV2Listener(GenericBaseModel):
- @NhFzm
+ @NLIjl
  def cloudformation_type():
   return "AWS::ElasticLoadBalancingV2::Listener"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -104,23 +104,23 @@ class ELBV2Listener(GenericBaseModel):
   proto=self.resolve_refs_recursively(stack_name,props.get("Protocol"),resources)
   port=self.resolve_refs_recursively(stack_name,props.get("Port"),resources)
   result=client.describe_listeners(LoadBalancerArn=lb_arn)["Listeners"]
-  port_candidates=[NhFzr(config.EDGE_PORT),NhFzr(config.EDGE_PORT_HTTP)]
-  result_filtered=[ls for ls in result if ls.get("LoadBalancerArn")==lb_arn and(NhFzr(port or "")in[NhFzr(ls.get("Port")),""]or NhFzr(ls.get("Port"))in port_candidates)and ls.get("Protocol")==proto]
+  port_candidates=[NLIjd(config.EDGE_PORT),NLIjd(config.EDGE_PORT_HTTP)]
+  result_filtered=[ls for ls in result if ls.get("LoadBalancerArn")==lb_arn and(NLIjd(port or "")in[NLIjd(ls.get("Port")),""]or NLIjd(ls.get("Port"))in port_candidates)and ls.get("Protocol")==proto]
   if result and not result_filtered:
    LOG.debug("No matching entry when filtering ELBv2 listeners %s for props %s"%(result,props))
-  return(result_filtered or[NhFzA])[0]
- @NhFzm
+  return(result_filtered or[NLIjz])[0]
+ @NLIjl
  def get_deploy_templates():
   def create_params(params,**kwargs):
    result=clone(params)
    for action in result.get("DefaultActions",[]):
     config=action.get("RedirectConfig",{})
     config["StatusCode"]=config.get("StatusCode")or "HTTP_301"
-    config["Port"]=config.get("Port")and NhFzr(config["Port"])
+    config["Port"]=config.get("Port")and NLIjd(config["Port"])
    return result
   return{"create":{"function":"create_listener","parameters":create_params}}
 class ELBV2LoadBalancer(GenericBaseModel):
- @NhFzm
+ @NLIjl
  def cloudformation_type():
   return "AWS::ElasticLoadBalancingV2::LoadBalancer"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -131,13 +131,13 @@ class ELBV2LoadBalancer(GenericBaseModel):
   client=aws_stack.connect_to_service("elbv2")
   result=client.describe_load_balancers()["LoadBalancers"]
   result=[bal for bal in result if bal["LoadBalancerName"]==bal_name]
-  return(result or[NhFzA])[0]
+  return(result or[NLIjz])[0]
  def get_cfn_attribute(self,attribute_name):
   if attribute_name=="DNSName":
    lb_arn=self.props.get("LoadBalancerArn")
-   return "%s.elb.%s"%(lb_arn.split("/")[2],ext_config.LOCAL_HOSTNAME)
-  return NhFzW(ELBV2LoadBalancer,self).get_cfn_attribute(attribute_name)
- @NhFzm
+   return "%s.elb.%s"%(lb_arn.split("/")[2],ext_config.RESOURCES_BASE_DOMAIN_NAME)
+  return NLIjE(ELBV2LoadBalancer,self).get_cfn_attribute(attribute_name)
+ @NLIjl
  def get_deploy_templates():
   def get_elbv2_loadbalancer_params(params,**kwargs):
    result=clone(params)
