@@ -1,46 +1,46 @@
 from localstack.services.cloudformation.service_models import REF_ATTRS,GenericBaseModel
-UEfCJ=staticmethod
-UEfCw=super
+aEmrO=staticmethod
+aEmrG=super
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import clone
 class GlueTrigger(GenericBaseModel):
- @UEfCJ
+ @aEmrO
  def cloudformation_type():
   return "AWS::Glue::Trigger"
  def get_cfn_attribute(self,attribute_name):
   if attribute_name in REF_ATTRS:
    return self.props.get("Name")
-  return UEfCw(GlueTrigger,self).get_cfn_attribute(attribute_name)
+  return aEmrG(GlueTrigger,self).get_cfn_attribute(attribute_name)
 class GlueWorkflow(GenericBaseModel):
- @UEfCJ
+ @aEmrO
  def cloudformation_type():
   return "AWS::Glue::Workflow"
  def get_cfn_attribute(self,attribute_name):
   if attribute_name in REF_ATTRS:
    return self.props.get("Name")
-  return UEfCw(GlueWorkflow,self).get_cfn_attribute(attribute_name)
+  return aEmrG(GlueWorkflow,self).get_cfn_attribute(attribute_name)
 class GlueJob(GenericBaseModel):
- @UEfCJ
+ @aEmrO
  def cloudformation_type():
   return "AWS::Glue::Job"
  def get_cfn_attribute(self,attribute_name):
   if attribute_name in REF_ATTRS:
    return self.props["Name"]
-  return UEfCw(GlueJob,self).get_cfn_attribute(attribute_name)
+  return aEmrG(GlueJob,self).get_cfn_attribute(attribute_name)
 class GlueCrawler(GenericBaseModel):
- @UEfCJ
+ @aEmrO
  def cloudformation_type():
   return "AWS::Glue::Crawler"
  def get_cfn_attribute(self,attribute_name):
   if attribute_name in REF_ATTRS:
    return self.props["Name"]
-  return UEfCw(GlueCrawler,self).get_cfn_attribute(attribute_name)
+  return aEmrG(GlueCrawler,self).get_cfn_attribute(attribute_name)
  def fetch_state(self,stack_name,resources):
   crawler_name=self.props.get("Name")or self.resource_id
   crawler_name=self.resolve_refs_recursively(stack_name,crawler_name,resources)
   client=aws_stack.connect_to_service("glue")
   return client.get_crawler(Name=crawler_name)["Crawler"]
- @UEfCJ
+ @aEmrO
  def get_deploy_templates():
   def lambda_get_crawler_config(params,**kwargs):
    config=clone(params)
@@ -50,15 +50,15 @@ class GlueCrawler(GenericBaseModel):
    return config
   return{"create":{"function":"create_crawler","parameters":lambda_get_crawler_config}}
 class GlueDatabase(GenericBaseModel):
- @UEfCJ
+ @aEmrO
  def cloudformation_type():
   return "AWS::Glue::Database"
  def get_cfn_attribute(self,attribute_name):
   if attribute_name in REF_ATTRS:
    return self.props.get("DatabaseInput",{}).get("Name")
-  return UEfCw(GlueDatabase,self).get_cfn_attribute(attribute_name)
+  return aEmrG(GlueDatabase,self).get_cfn_attribute(attribute_name)
 class GlueClassifier(GenericBaseModel):
- @UEfCJ
+ @aEmrO
  def cloudformation_type():
   return "AWS::Glue::Classifier"
  def get_cfn_attribute(self,attribute_name):
@@ -66,13 +66,13 @@ class GlueClassifier(GenericBaseModel):
    result=(self.props.get("GrokClassifier",{}).get("Name")or self.props.get("CsvClassifier",{}).get("Name")or self.props.get("JsonClassifier",{}).get("Name")or self.props.get("XMLClassifier",{}).get("Name"))
    if result:
     return result
-  return UEfCw(GlueCrawler,self).get_cfn_attribute(attribute_name)
+  return aEmrG(GlueCrawler,self).get_cfn_attribute(attribute_name)
 class GlueTable(GenericBaseModel):
- @UEfCJ
+ @aEmrO
  def cloudformation_type():
   return "AWS::Glue::Table"
  def get_cfn_attribute(self,attribute_name):
   if attribute_name in REF_ATTRS:
    return self.props.get("TableInput",{}).get("Name")
-  return UEfCw(GlueTable,self).get_cfn_attribute(attribute_name)
+  return aEmrG(GlueTable,self).get_cfn_attribute(attribute_name)
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
