@@ -1,16 +1,16 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-gzqWu=staticmethod
-gzqWo=classmethod
+kwyOg=staticmethod
+kwyOm=classmethod
 from localstack.utils.aws import aws_stack
 class IoTCertificate(GenericBaseModel):
- @gzqWu
+ @kwyOg
  def cloudformation_type():
   return "AWS::IoT::Certificate"
  def fetch_state(self,stack_name,resources):
   return self.state.get("certificateId")
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("certificateId")
- @gzqWo
+ @kwyOm
  def get_deploy_templates(cls):
   def create_certificate_from_csr(resource_id,resources,*args,**kwargs):
    client=aws_stack.connect_to_service("iot")
