@@ -1,10 +1,10 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-GuFrX=staticmethod
-GuFrN=None
-GuFrY=all
+ROniF=staticmethod
+ROniG=None
+ROnij=all
 from localstack.utils.aws import aws_stack
 class SESTemplate(GenericBaseModel):
- @GuFrX
+ @ROniF
  def cloudformation_type():
   return "AWS::SES::Template"
  def fetch_state(self,stack_name,resources):
@@ -13,18 +13,18 @@ class SESTemplate(GenericBaseModel):
   tmpl_name=self.resolve_refs_recursively(stack_name,template_name,resources)
   templates=client.list_templates().get("TemplatesMetadata",[])
   template=[t for t in templates if t["Name"]==tmpl_name]
-  return(template or[GuFrN])[0]
- def get_physical_resource_id(self,attribute=GuFrN,**kwargs):
+  return(template or[ROniG])[0]
+ def get_physical_resource_id(self,attribute=ROniG,**kwargs):
   return self.props.get("Template",{}).get("TemplateName")
  def update_resource(self,new_resource,stack_name,resources):
   client=aws_stack.connect_to_service("ses")
   new_props=new_resource["Properties"]
   new_template=new_props.get("Template",{})
   template=client.get_template(TemplateName=new_template["TemplateName"])["Template"]
-  if GuFrY(template.get(attr,"")==new_template.get(attr,"")for attr in["SubjectPart","TextPart","HtmlPart"]):
+  if ROnij(template.get(attr,"")==new_template.get(attr,"")for attr in["SubjectPart","TextPart","HtmlPart"]):
    return
   return client.update_template(**new_props)
- @GuFrX
+ @ROniF
  def get_deploy_templates():
   return{"create":{"function":"create_template"},"delete":{"function":"delete_template","parameters":{"TemplateName":"TemplateName"}}}
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
